'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function (command, flags) {
    (function () {
        switch (command) {
            case 'test':
                var filePath = _path2.default.resolve(process.cwd(), flags.src || defaults.file);
                var config = JSON.parse(_gracefulFs2.default.readFileSync(filePath), 'utf8');

                var _Object$assign = Object.assign({}, defaults.config, config),
                    host = _Object$assign.host,
                    tests = _Object$assign.tests,
                    platforms = _Object$assign.platforms;

                platforms.map(function (platform) {
                    return function () {
                        return (0, _runner2.default)(tests, host, platform);
                    };
                }).reduce(_q2.default.when, (0, _q2.default)()); // eslint-disable-line
                break;
            case 'init':
                console.log('Hi, I will help you to setup chatic for this project.');

                var questions = [{
                    type: 'input',
                    message: 'Enter the name of file for chatic config or just press enter',
                    name: 'file',
                    default: defaults.file,
                    validate: function validate() {
                        return true;
                    }
                }, {
                    type: 'input',
                    message: 'Enter path to tests',
                    name: 'tests',
                    default: defaults.config.tests,
                    validate: function validate() {
                        return true;
                    }
                }, {
                    type: 'checkbox',
                    message: 'Select platforms',
                    name: 'platforms',
                    choices: [{
                        name: 'facebook'
                    }, {
                        name: 'slack'
                    }],
                    validate: function validate(answer) {
                        if (answer.length < 1) {
                            return 'You must choose at least one platform.';
                        }
                        return true;
                    }
                }, {
                    type: 'expand',
                    message: 'Do you want to set up custom server?',
                    name: 'server',
                    choices: [{
                        key: 'y',
                        name: 'Yes',
                        value: true
                    }, {
                        key: 'n',
                        name: 'No',
                        value: false
                    }]
                }, {
                    type: 'input',
                    message: 'Please provide link to custom server',
                    name: 'host',
                    default: defaults.config.host,
                    when: function when(answers) {
                        return answers.server;
                    }
                }];

                _inquirer2.default.prompt(questions).then(function (answers) {
                    var conf = Object.assign({}, answers);
                    var file = _path2.default.resolve(process.cwd(), answers.file === '' ? defaults.file : answers.file);

                    delete conf.server;

                    _gracefulFs2.default.writeFileSync(file, JSON.stringify(conf, null, 4), 'utf8');

                    console.log(_chalk2.default.green('Hooray! You are ready to test.'));
                });
                break;
            default:
                console.log('\n            Don\'t know \'' + command + '\'.\n            Please use ' + _chalk2.default.green('chatic help') + ' for getting more information.\n        ');
        }
    })();
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _gracefulFs = require('graceful-fs');

var _gracefulFs2 = _interopRequireDefault(_gracefulFs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _q = require('q');

var _q2 = _interopRequireDefault(_q);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _runner = require('./runner');

var _runner2 = _interopRequireDefault(_runner);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaults = {
    file: '.chaticconf',
    config: {
        host: 'https://demo.chatic.io',
        tests: './test/**/*.js',
        platforms: []
    }
};

Object.freeze(defaults);