'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mocha = require('mocha');

var _mocha2 = _interopRequireDefault(_mocha);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _q = require('q');

var _q2 = _interopRequireDefault(_q);

var _cliSpinner = require('cli-spinner');

var _api = require('./api');

var _api2 = _interopRequireDefault(_api);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (tests, host, platform) {
    Object.keys(require.cache).forEach(function (file) {
        return delete require.cache[file];
    });
    var deferred = _q2.default.defer();
    var files = _glob2.default.sync(tests, { absolute: true });
    var api = (0, _api2.default)(host, platform);
    var mocha = new _mocha2.default({ timeout: 30000 });
    var spinner = new _cliSpinner.Spinner('%s Connecting to idle node...');
    var onError = function onError() {
        console.log(_chalk2.default.green('Can\'t find idle node for testing'));
        deferred.reject();
    };

    spinner.setSpinnerString(0);
    spinner.start();

    api.connect().then(function (response, httpResponse) {
        spinner.stop();

        switch (httpResponse.statusCode) {
            case 200:
                console.log('\n' + _chalk2.default.green('Connected'));
                global.chatic = api;

                files.forEach(function (file) {
                    return mocha.addFile(file);
                });

                mocha.run(function (failures) {
                    process.on('exit', function () {
                        return api.disconnect().then(function () {
                            return process.exit(failures);
                        });
                    }); // eslint-disable-line
                }).on('end', function () {
                    api.disconnect().then(function () {
                        delete global.chatic;
                        deferred.resolve();
                    });
                });
                break;
            default:
                onError();
        }
    }, onError);

    return deferred.promise;
};